# DeviceTxBuffer

Device message buffer model used for API and database. Internal usage.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**message_id** | **str** |  | 
**timestamp** | **int** |  | [optional] 
**device_message** | **str** |  | [optional] 
**device_id** | **str** |  | [optional] 
**device_serial** | **str** |  | [optional] 
**device_type** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


